# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/queuestatemanager/v1/queuestatemanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n<public/llmcloud/queuestatemanager/v1/queuestatemanager.proto\x12$public.llmcloud.queuestatemanager.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto"0\n\x16GetRequestStateRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id"O\n\x17GetRequestStateResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12$\n\x0eplace_in_queue\x18\x02 \x01(\x05R\x0cplaceInQueue2\xdf\x01\n\x18QueueStateManagerService\x12\xc2\x01\n\x0fGetRequestState\x12<.public.llmcloud.queuestatemanager.v1.GetRequestStateRequest\x1a=.public.llmcloud.queuestatemanager.v1.GetRequestStateResponse"2\x82\xd3\xe4\x93\x02,\x12*/v1/queue_state_manager/request_state/{id}B\xcc\x02\n(com.public.llmcloud.queuestatemanager.v1B\x16QueuestatemanagerProtoP\x01ZSgit.groq.io/cloud/go-proto/public/llmcloud/queuestatemanager/v1;queuestatemanagerv1\xa2\x02\x03PLQ\xaa\x02$Public.Llmcloud.Queuestatemanager.V1\xca\x02%Public_\\Llmcloud\\Queuestatemanager\\V1\xe2\x02\x31Public_\\Llmcloud\\Queuestatemanager\\V1\\GPBMetadata\xea\x02\'Public::Llmcloud::Queuestatemanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.queuestatemanager.v1.queuestatemanager_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n(com.public.llmcloud.queuestatemanager.v1B\026QueuestatemanagerProtoP\001ZSgit.groq.io/cloud/go-proto/public/llmcloud/queuestatemanager/v1;queuestatemanagerv1\242\002\003PLQ\252\002$Public.Llmcloud.Queuestatemanager.V1\312\002%Public_\\Llmcloud\\Queuestatemanager\\V1\342\0021Public_\\Llmcloud\\Queuestatemanager\\V1\\GPBMetadata\352\002'Public::Llmcloud::Queuestatemanager::V1"
    _globals["_GETREQUESTSTATEREQUEST"].fields_by_name["id"]._options = None
    _globals["_GETREQUESTSTATEREQUEST"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\003\310\001\001"
    _globals["_QUEUESTATEMANAGERSERVICE"].methods_by_name[
        "GetRequestState"
    ]._options = None
    _globals["_QUEUESTATEMANAGERSERVICE"].methods_by_name[
        "GetRequestState"
    ]._serialized_options = (
        b"\202\323\344\223\002,\022*/v1/queue_state_manager/request_state/{id}"
    )
    _globals["_GETREQUESTSTATEREQUEST"]._serialized_start = 161
    _globals["_GETREQUESTSTATEREQUEST"]._serialized_end = 209
    _globals["_GETREQUESTSTATERESPONSE"]._serialized_start = 211
    _globals["_GETREQUESTSTATERESPONSE"]._serialized_end = 290
    _globals["_QUEUESTATEMANAGERSERVICE"]._serialized_start = 293
    _globals["_QUEUESTATEMANAGERSERVICE"]._serialized_end = 516
# @@protoc_insertion_point(module_scope)
