# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/globalstatsmanager/v1/globalstatsmanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n>public/llmcloud/globalstatsmanager/v1/globalstatsmanager.proto\x12%public.llmcloud.globalstatsmanager.v1\x1a\x1cgoogle/api/annotations.proto"\x17\n\x15GetGlobalStatsRequest"N\n\x16GetGlobalStatsResponse\x12\x34\n\x16total_requests_counter\x18\x01 \x01(\rR\x14totalRequestsCounter2\xda\x01\n\x19GlobalStatsManagerService\x12\xbc\x01\n\x0eGetGlobalStats\x12<.public.llmcloud.globalstatsmanager.v1.GetGlobalStatsRequest\x1a=.public.llmcloud.globalstatsmanager.v1.GetGlobalStatsResponse"-\x82\xd3\xe4\x93\x02\'\x12%/v1/global_stats_manager/global_statsB\xd4\x02\n)com.public.llmcloud.globalstatsmanager.v1B\x17GlobalstatsmanagerProtoP\x01ZUgit.groq.io/cloud/go-proto/public/llmcloud/globalstatsmanager/v1;globalstatsmanagerv1\xa2\x02\x03PLG\xaa\x02%Public.Llmcloud.Globalstatsmanager.V1\xca\x02&Public_\\Llmcloud\\Globalstatsmanager\\V1\xe2\x02\x32Public_\\Llmcloud\\Globalstatsmanager\\V1\\GPBMetadata\xea\x02(Public::Llmcloud::Globalstatsmanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.globalstatsmanager.v1.globalstatsmanager_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n)com.public.llmcloud.globalstatsmanager.v1B\027GlobalstatsmanagerProtoP\001ZUgit.groq.io/cloud/go-proto/public/llmcloud/globalstatsmanager/v1;globalstatsmanagerv1\242\002\003PLG\252\002%Public.Llmcloud.Globalstatsmanager.V1\312\002&Public_\\Llmcloud\\Globalstatsmanager\\V1\342\0022Public_\\Llmcloud\\Globalstatsmanager\\V1\\GPBMetadata\352\002(Public::Llmcloud::Globalstatsmanager::V1"
    _globals["_GLOBALSTATSMANAGERSERVICE"].methods_by_name[
        "GetGlobalStats"
    ]._options = None
    _globals["_GLOBALSTATSMANAGERSERVICE"].methods_by_name[
        "GetGlobalStats"
    ]._serialized_options = (
        b"\202\323\344\223\002'\022%/v1/global_stats_manager/global_stats"
    )
    _globals["_GETGLOBALSTATSREQUEST"]._serialized_start = 135
    _globals["_GETGLOBALSTATSREQUEST"]._serialized_end = 158
    _globals["_GETGLOBALSTATSRESPONSE"]._serialized_start = 160
    _globals["_GETGLOBALSTATSRESPONSE"]._serialized_end = 238
    _globals["_GLOBALSTATSMANAGERSERVICE"]._serialized_start = 241
    _globals["_GLOBALSTATSMANAGERSERVICE"]._serialized_end = 459
# @@protoc_insertion_point(module_scope)
