# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/modelmanager/v1/modelmanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from public.llmcloud.modelmanager.v1 import (
    model_pb2 as public_dot_llmcloud_dot_modelmanager_dot_v1_dot_model__pb2,
)

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n2public/llmcloud/modelmanager/v1/modelmanager.proto\x12\x1fpublic.llmcloud.modelmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a+public/llmcloud/modelmanager/v1/model.proto"\x13\n\x11ListModelsRequest"T\n\x12ListModelsResponse\x12>\n\x06models\x18\x01 \x03(\x0b\x32&.public.llmcloud.modelmanager.v1.ModelR\x06models2\xaf\x01\n\x13ModelManagerService\x12\x97\x01\n\nListModels\x12\x32.public.llmcloud.modelmanager.v1.ListModelsRequest\x1a\x33.public.llmcloud.modelmanager.v1.ListModelsResponse" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/model_manager/modelsB\xa4\x02\n#com.public.llmcloud.modelmanager.v1B\x11ModelmanagerProtoP\x01ZIgit.groq.io/cloud/go-proto/public/llmcloud/modelmanager/v1;modelmanagerv1\xa2\x02\x03PLM\xaa\x02\x1fPublic.Llmcloud.Modelmanager.V1\xca\x02 Public_\\Llmcloud\\Modelmanager\\V1\xe2\x02,Public_\\Llmcloud\\Modelmanager\\V1\\GPBMetadata\xea\x02"Public::Llmcloud::Modelmanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.modelmanager.v1.modelmanager_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b'\n#com.public.llmcloud.modelmanager.v1B\021ModelmanagerProtoP\001ZIgit.groq.io/cloud/go-proto/public/llmcloud/modelmanager/v1;modelmanagerv1\242\002\003PLM\252\002\037Public.Llmcloud.Modelmanager.V1\312\002 Public_\\Llmcloud\\Modelmanager\\V1\342\002,Public_\\Llmcloud\\Modelmanager\\V1\\GPBMetadata\352\002"Public::Llmcloud::Modelmanager::V1'
    _globals["_MODELMANAGERSERVICE"].methods_by_name["ListModels"]._options = None
    _globals["_MODELMANAGERSERVICE"].methods_by_name[
        "ListModels"
    ]._serialized_options = b"\202\323\344\223\002\032\022\030/v1/model_manager/models"
    _globals["_LISTMODELSREQUEST"]._serialized_start = 162
    _globals["_LISTMODELSREQUEST"]._serialized_end = 181
    _globals["_LISTMODELSRESPONSE"]._serialized_start = 183
    _globals["_LISTMODELSRESPONSE"]._serialized_end = 267
    _globals["_MODELMANAGERSERVICE"]._serialized_start = 270
    _globals["_MODELMANAGERSERVICE"]._serialized_end = 445
# @@protoc_insertion_point(module_scope)
